@@ -15,20 +15,17 @@ from contextlib import contextmanager
 
 import pytest
 
-from tests import unittest, mock, BaseSessionTest, ClientHTTPStubber
-
 from botocore import exceptions
-from botocore.exceptions import (
-    UnsupportedS3ControlArnError,
-    UnsupportedS3ControlConfigurationError,
-    InvalidHostLabelError,
-    ParamValidationError,
-)
-from botocore.session import Session
 from botocore.compat import urlsplit
 from botocore.config import Config
-from botocore.awsrequest import AWSResponse
-
+from botocore.exceptions import (
+    InvalidHostLabelError,
+    ParamValidationError,
+    UnsupportedS3ControlArnError,
+    UnsupportedS3ControlConfigurationError,
+)
+from botocore.session import Session
+from tests import ClientHTTPStubber, unittest
 
 ACCESSPOINT_ARN_TEST_CASES = [
     # Outpost accesspoint arn test cases
@@ -95,24 +92,29 @@ ACCESSPOINT_ARN_TEST_CASES = [
         'region': 'us-gov-east-1-fips',
         'config': {'s3': {'use_arn_region': False}},
         'assertions': {
-            'exception': 'UnsupportedS3ControlConfigurationError',
+            'signing_name': 's3-outposts',
+            'netloc': 's3-outposts-fips.us-gov-east-1.amazonaws.com',
+            'headers': {
+                'x-amz-outpost-id': 'op-01234567890123456',
+                'x-amz-account-id': '123456789012',
+            },
         }
     },
-    #{
+    # {
     #    'arn': 'arn:aws-us-gov:s3-outposts:fips-us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
     #    'region': 'fips-us-gov-east-1',
     #    'config': {'s3': {'use_arn_region': True}},
     #    'assertions': {
     #        'exception': 'UnsupportedS3ArnError',
     #    }
-    #},
+    # },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
         'region': 'us-gov-east-1-fips',
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'signing_name': 's3-outposts',
-            'netloc': 's3-outposts.us-gov-east-1.amazonaws.com',
+            'netloc': 's3-outposts-fips.us-gov-east-1.amazonaws.com',
             'headers': {
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
@@ -216,7 +218,12 @@ BUCKET_ARN_TEST_CASES = [
         'region': 'us-gov-east-1-fips',
         'config': {'s3': {'use_arn_region': False}},
         'assertions': {
-            'exception': 'UnsupportedS3ControlConfigurationError',
+            'signing_name': 's3-outposts',
+            'netloc': 's3-outposts-fips.us-gov-east-1.amazonaws.com',
+            'headers': {
+                'x-amz-outpost-id': 'op-01234567890123456',
+                'x-amz-account-id': '123456789012',
+            },
         }
     },
     {
@@ -224,7 +231,7 @@ BUCKET_ARN_TEST_CASES = [
         'region': 'fips-us-gov-east-1',
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
-            'exception': 'UnsupportedS3ControlConfigurationError',
+            'exception': 'UnsupportedS3ControlArnError',
         }
     },
     {
@@ -233,7 +240,7 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'signing_name': 's3-outposts',
-            'netloc': 's3-outposts.us-gov-east-1.amazonaws.com',
+            'netloc': 's3-outposts-fips.us-gov-east-1.amazonaws.com',
             'headers': {
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
